# Tables

### Simple Table

A simple table in Markdown is created by using vertical bars (|) to separate columns and hyphens (-) to define the table header. Each row is represented as a separate line, with the content of each cell separated by vertical bars.

    First Header  | Second Header
    ------------- | -------------
    Content Cell  | Content Cell
    Content Cell  | Content Cell

#### Example

First Header | Second Header
--- | ---
Content Cell | Content Cell
Content Cell | Content Cell

### Aligned Table

An aligned table in Markdown allows you to specify the alignment of the content within each cell. It is created by using colons (:) to indicate the alignment of the columns. A colon on the left side indicates left alignment, a colon on the right side indicates right alignment, and colons on both sides indicate center alignment.

     Left Header |  Center Header  | Right Header
    :----------- | :-------------: | ------------:
     Conent Cell |  Content Cell   | Content Cell

#### Example

Left Header | Center Header | Right Header
--- | --- | ---
Conent Cell | Content Cell | Content Cell